summaryrefslogtreecommitdiffstats
path: root/hl/examples/ex_table_08.c
diff options
context:
space:
mode:
Diffstat (limited to 'hl/examples/ex_table_08.c')
-rw-r--r--hl/examples/ex_table_08.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/hl/examples/ex_table_08.c b/hl/examples/ex_table_08.c
index 4e1d754..6ec0ac1 100644
--- a/hl/examples/ex_table_08.c
+++ b/hl/examples/ex_table_08.c
@@ -134,7 +134,10 @@ int main( void )
}
- /* Close the file. */
+ /* close type */
+ H5Tclose( string_type );
+
+ /* close the file */
H5Fclose( file_id );
return 0;